@@ -34,7 +34,7 @@ def add_log_file(log_file: str, project_name: str = None):
         "default": PROJECT_NAME,
         "true": PROJECT_NAME,
         "false": None,
-    }.get[str(log_file).lower(), log_file]
+    }.get(str(log_file).lower(), log_file)
 
     if log_file:
         log_dir = appdirs.user_log_dir(PROJECT_NAME, "cleargrid")
